@@ -1,5 +1,8 @@
 import copy
 import inspect
+from functools import (
+    lru_cache,
+)
 from itertools import (
     chain,
 )
@@ -71,7 +74,7 @@ def _has_contribute_to_class(value):
 
 class ModelEnumValue:
     """
-    Значение модели-перечисления
+    Значение модели-перечисления.
 
     Универсальная сущность, которая используется в качестве значений параметров класса модели-перечисления наследника
     m3_db_utils.models.ModelEnum. Должны быть заполнены поля, обозначенные в моделе, как обязательные. Иначе не будет
@@ -109,27 +112,27 @@ class ModelEnumValue:
     @property
     def key(self) -> str:
         """
-        Возвращает ключ
+        Возвращает ключ.
         """
         return self._key
 
     @key.setter
     def key(self, v):
         """
-        Устанавливает ключ
+        Устанавливает ключ.
         """
         self._key = v
 
     @property
     def fields(self) -> List[str]:
         """
-        Возвращает список полей значения модели-перечисления
+        Возвращает список полей значения модели-перечисления.
         """
         return self._fields
 
     def set_field_value(self, field_name: str, field_value: Any, force: bool = False):
         """
-        Установка значения поля
+        Установка значения поля.
 
         Args:
             field_name: имя поля
@@ -141,7 +144,7 @@ class ModelEnumValue:
 
     def set_required_field(self, field_name):
         """
-        Установка обязательности поля в значении модели-перечисления
+        Установка обязательности поля в значении модели-перечисления.
         """
         if getattr(self, field_name, None) is None:
             raise RequiredFieldEmptyModelEnumValueError
@@ -151,14 +154,14 @@ class ModelEnumValue:
     @cached_property
     def required_fields(self):
         """
-        Возвращает список обязательных для заполнения полей значения модели-перечисления
+        Возвращает список обязательных для заполнения полей значения модели-перечисления.
         """
         return self._required_fields
 
     @cached_property
     def required_fields_without_key(self):
         """
-        Возвращает список обязательных для заполнения полей значения модели-перечисления без поля key
+        Возвращает список обязательных для заполнения полей значения модели-перечисления без поля key.
         """
         required_fields = copy.deepcopy(self.required_fields)
         required_fields.remove(KEY_FIELD_NAME)
@@ -169,7 +172,7 @@ class ModelEnumValue:
 class ModelEnumMetaclass(ModelBase):
     """
     Метакласс для моделей-перечислений с переопределенным набором параметров в Meta. Поведение достигается путем замены
-    стандартного Options на кастомный
+    стандартного Options на кастомный.
     """
 
     # TODO BOBUH-19054
@@ -440,7 +443,7 @@ class ModelEnumMetaclass(ModelBase):
     @classmethod
     def _patch_model_enum_values(cls, attrs: Dict[str, Any]):
         """
-        Патчинг параметров моделей-перечислений с добавлением ключей
+        Патчинг параметров моделей-перечислений с добавлением ключей.
         """
         for key, value in attrs.items():
             if isinstance(value, ModelEnumValue):
@@ -450,7 +453,7 @@ class ModelEnumMetaclass(ModelBase):
     def _set_default_model_enum_values(new_class, attrs: Dict[str, Any]):
         """
         Установка дефолтных значений из полей модели в поля значения модели-перечисления, если значения еще не были
-        заполнены
+        заполнены.
         """
         fields_with_default_values = [
             field
@@ -478,7 +481,7 @@ class ModelEnumMetaclass(ModelBase):
     @staticmethod
     def _set_model_enum_value_required_fields(new_class, attrs: Dict[str, Any]):
         """
-        Добавление обязательных для заполнения полей в значении модели-перечисления
+        Добавление обязательных для заполнения полей в значении модели-перечисления.
         """
         required_fields = []
 
@@ -508,7 +511,7 @@ class ModelEnumMetaclass(ModelBase):
     @classmethod
     def _patch_new_class_after_init(cls, new_class, attrs: Dict[str, Any]):
         """
-        Патчинг сформированного класса модели после его инициализации
+        Патчинг сформированного класса модели после его инициализации.
         """
         cls._set_default_model_enum_values(new_class=new_class, attrs=attrs)
         cls._set_model_enum_value_required_fields(new_class=new_class, attrs=attrs)
@@ -516,7 +519,7 @@ class ModelEnumMetaclass(ModelBase):
 
 class ModelEnum(Model, metaclass=ModelEnumMetaclass):
     """
-    Модель-перечисление
+    Модель-перечисление.
 
     Предназначен для создания перечислений, которые будут храниться в базе данных. На значения перечислений можно
     ссылаться через внешний ключ. Данный подход является более удобным с точки зрения работы на уровне SQL -
@@ -566,9 +569,10 @@ class ModelEnum(Model, metaclass=ModelEnumMetaclass):
         abstract = True
 
     @classmethod
+    @lru_cache()
     def get_enum_data(cls) -> Dict[str, ModelEnumValue]:
         """
-        Возвращает данные перечисления в виде словаря
+        Возвращает данные перечисления в виде словаря.
 
         Args:
 
@@ -594,10 +598,26 @@ class ModelEnum(Model, metaclass=ModelEnumMetaclass):
 
         return enum_data
 
+    @classmethod
+    @lru_cache()
+    def get_model_enum_values(cls) -> List[ModelEnumValue]:
+        """
+        Получение значений модели перечисления.
+        """
+        return list(cls.get_enum_data().values())
+
+    @classmethod
+    @lru_cache()
+    def get_model_enum_keys(cls) -> List[str]:
+        """
+        Получение значений модели перечисления.
+        """
+        return list(cls.get_enum_data().keys())
+
     @classmethod
     def get_model_enum_value(cls, key: str) -> ModelEnumValue:
         """
-        Возвращает значение элемента перечисления
+        Возвращает значение элемента перечисления.
 
         Args:
 
@@ -612,7 +632,7 @@ class ModelEnum(Model, metaclass=ModelEnumMetaclass):
     def extend(cls, key, order_number=DEFAULT_ORDER_NUMBER, **kwargs):
         """
         Метод расширения модели-перечисления, например из плагина. Необходимо, чтобы сама модель-перечисление была
-        расширяемой. Для этого необходимо, чтобы был установлен extensible = True в Meta
+        расширяемой. Для этого необходимо, чтобы был установлен extensible = True в Meta.
 
         Args:
             key: ключ элемента перечисления, указывается заглавными буквами с разделителем нижнее подчеркивание
@@ -623,14 +643,14 @@ class ModelEnum(Model, metaclass=ModelEnumMetaclass):
     @property
     def model_enum_value(self) -> ModelEnumValue:
         """
-        Получение значения модели-перечисления у экземпляра модели
+        Получение значения модели-перечисления у экземпляра модели.
         """
         return getattr(self, self.key)
 
 
 class IntegerModelEnum(ModelEnum, IntegerValueMixin):
     """
-    Модель-перечисление c обязательным для заполнения целочисленным положительным полем value
+    Модель-перечисление c обязательным для заполнения целочисленным положительным полем value.
     """
 
     class Meta:
@@ -639,7 +659,7 @@ class IntegerModelEnum(ModelEnum, IntegerValueMixin):
 
 class CharModelEnum(ModelEnum, CharValueMixin):
     """
-    Модель-перечисление c обязательным для заполнения символьным полем value
+    Модель-перечисление c обязательным для заполнения символьным полем value.
     """
 
     class Meta:
@@ -648,7 +668,7 @@ class CharModelEnum(ModelEnum, CharValueMixin):
 
 class TitledModelEnum(ModelEnum, TitleFieldMixin):
     """
-    Модель-перечисление c обязательным для заполнения текстовым полем title
+    Модель-перечисление c обязательным для заполнения текстовым полем title.
     """
 
     class Meta:
@@ -657,7 +677,7 @@ class TitledModelEnum(ModelEnum, TitleFieldMixin):
 
 class TitledIntegerModelEnum(IntegerModelEnum, TitleFieldMixin):
     """
-    Модель-перечисление c обязательными для заполнения целочисленным положительным полем value и текстовым полем title
+    Модель-перечисление c обязательными для заполнения целочисленным положительным полем value и текстовым полем title.
     """
 
     class Meta:
@@ -666,7 +686,7 @@ class TitledIntegerModelEnum(IntegerModelEnum, TitleFieldMixin):
 
 class TitledCharModelEnum(CharModelEnum, TitleFieldMixin):
     """
-    Модель-перечисление c символьным полем value и текстовым полем title
+    Модель-перечисление c символьным полем value и текстовым полем title.
     """
 
     class Meta:
